String repositoryGenerator(String name) => '''
import 'package:easy/easy.dart';
import 'package:http/http.dart' as http;
import 'dart:io';

const BASE_URL = "https://jsonplaceholder.typicode.com/posts/1";

class ${name}Repository extends Disposable {

 Future<dynamic> get(String url) async {
  var responseJson;
  try {
    final response = await  HttpInstance().client.get(BASE_URL + url);
    responseJson = _returnResponse(response);
  } on SocketException {
    print('No net');
    throw FetchDataException('No Internet connection');
  }

  return responseJson;
}

Future<dynamic> post(String url, dynamic body) async {
  var responseJson;
  try {
    final response = await HttpInstance().client.post(BASE_URL + url, body: body);
    responseJson = _returnResponse(response);
  } on SocketException {
    throw FetchDataException('No Internet connection');
  }

  return responseJson;
}

Future<dynamic> put(String url, dynamic body) async {
  var responseJson;
  try {
    final response = await  HttpInstance().client.put(BASE_URL + url, body: body);
    responseJson = _returnResponse(response);
  } on SocketException {
    throw FetchDataException('No Internet connection');
  }

  return responseJson;
}

Future<dynamic> delete(String url) async {
  var apiResponse;
  try {
    final response = await  HttpInstance().client.delete(BASE_URL + url);
    apiResponse = _returnResponse(response);
  } on SocketException {
    throw FetchDataException('No Internet connection');
  }

  return apiResponse;
}

dynamic _returnResponse(http.Response response) {
  switch (response.statusCode) {
    case 200:
      var responseJson = json.decode(response.body.toString());
      print(responseJson);
      return responseJson;
    case 400:
      throw BadRequestException(response.body.toString());
    case 401:
    case 403:
      throw UnauthorisedException(response.body.toString());
    case 500:
    default:
      throw FetchDataException(
          'Error occured while Communication with Server');
  }
}


  //dispose will be called automatically
  @override
  void dispose() {
    HttpInstance().dispose();
  }

}

class AppException implements Exception {
  final _message;
  final _prefix;

  AppException([this._message, this._prefix]);

 
}

class FetchDataException extends AppException {
  FetchDataException([String message])
      : super(message, "Error During Communication: ");
}

class BadRequestException extends AppException {
  BadRequestException([message]) : super(message, "Invalid Request: ");
}

class UnauthorisedException extends AppException {
  UnauthorisedException([message]) : super(message, "Unauthorised: ");
}

class InvalidInputException extends AppException {
  InvalidInputException([String message]) : super(message, "Invalid Input: ");
}


  ''';
